@@ -52,6 +52,18 @@ class ArtellaDccPlugin(object):
 
         return self._dev
 
+    @property
+    def version(self):
+        """
+        Returns current DCC plugin version
+        :return: str or None
+        """
+
+        version_var = 'ARTELLA_{}_PLUGIN'.format(dcc.name())
+        plugin_version = os.environ.get(version_var, None)
+
+        return plugin_version
+
     # ==============================================================================================================
     # INITIALIZATION / SHUTDOWN
     # ==============================================================================================================
@@ -67,12 +79,14 @@ class ArtellaDccPlugin(object):
 
         pass
 
-    def init(self, dev=False, show_dialogs=True):
+    def init(self, dev=False, show_dialogs=True, create_menu=True, create_callbacks=True, *args, **kwargs):
         """
         Initializes Artella plugin in current DCC.
 
         :param bool dev: Whether plugin is initialized in development mode or not
         :param bool show_dialogs: Whether dialogs should appear during plugin initialization or not
+        :param bool create_menu: Whether menu should be created or not
+        :param bool create_callbacks: Whether or not DCC callbacks should be created
         :return: True if the initialization was successful; False otherwise.
         :rtype: bool
         """
@@ -80,10 +94,12 @@ class ArtellaDccPlugin(object):
         self._dev = dev
 
         # Initialize Artella callbacks
-        self.setup_callbacks()
+        if create_callbacks:
+            self.setup_callbacks()
 
         # Create Artella DCC Menu
-        dcc.execute_deferred(self.create_menus)
+        if create_menu:
+            dcc.execute_deferred(self.create_menus)
 
         # Initialize Artella Drive client
         self.init_client(show_dialogs=show_dialogs)
@@ -429,6 +445,26 @@ class ArtellaDccPlugin(object):
 
         return artella_drive_client.translate_path(file_path)
 
+    def is_path_translated(self, file_path):
+        """
+        Returns whether or not given path is already translated to a valid Artella path
+
+        :param file_path: str, path you want to check translation validation
+        :return: True if the given path is an already translated Artella path; False otherwise
+        :rtype: bool
+        :example:
+        >>> self.is_path_translated("C:/Users/Bobby/artella-files/ProjectA/Assets/Characters/A/Model/a.ma")
+        False
+        >>> self.is_path_translated("$ART_LOCAL_ROOT/ProjectA/refs/ref.png")
+        True
+        """
+
+        artella_drive_client = self.get_client(show_dialogs=False)
+        if not artella_drive_client:
+            return False
+
+        return artella_drive_client.is_path_translated(file_path)
+
     def convert_path(self, file_path):
         """
         Converts given path to a path that Artella can understand
@@ -449,6 +485,7 @@ class ArtellaDccPlugin(object):
 
         return artella_drive_client.convert_path(file_path)
 
+    @utils.timestamp
     def update_paths(self, file_path=None, show_dialogs=True, call_post_function=True, skip_save=True):
         """
         Updates all file paths of the given file path to make sure that they point to valid Artella file paths
@@ -474,6 +511,7 @@ class ArtellaDccPlugin(object):
 
         file_paths = utils.force_list(file_path, remove_duplicates=True)
 
+        converted_paths = list()
         for file_path in file_paths:
 
             local_path = artella_drive_client.translate_path(file_path)
@@ -493,13 +531,16 @@ class ArtellaDccPlugin(object):
                 dcc.open_scene(file_path, save=True)
 
             parser = artella.Parser()
-            valid_convert = parser.update_paths(local_path)
+            valid_convert, updated_paths = parser.update_paths(local_path)
+            updated_paths = utils.force_list(updated_paths)
+            converted_paths.extend(updated_paths)
 
-            if valid_convert and not skip_save:
+            if valid_convert and updated_paths and not skip_save:
                 dcc.save_scene()
 
-        if call_post_function:
-            self._post_update_paths()
+        converted_paths = list(set(converted_paths))
+        if call_post_function and converted_paths:
+            self._post_update_paths(files_updated=converted_paths)
 
     # ==============================================================================================================
     # VERSIONS
@@ -769,6 +810,21 @@ class ArtellaDccPlugin(object):
 
         local_path = artella_drive_client.translate_path(file_path)
 
+        remote_file_size = 0
+        file_status = artella_drive_client.status(local_path, include_remote=True)
+        if not file_status:
+            logger.warning('File "{}" not found in remote'.format(file_status))
+            return False
+        file_status = file_status[0]
+        for version_id, version_data in file_status.items():
+            if not version_id or not version_id.startswith('project__'):
+                continue
+            remote_file_size = version_data.get('remote_info', dict()).get('content_length', 0)
+            break
+        if not remote_file_size:
+            logger.warning('File "{}" in remote has not a valid file size: {}'.format(local_path, remote_file_size))
+            return False
+
         if show_dialogs:
             dcc_progress_bar = splash.ProgressSplashDialog()
             dcc_progress_bar.start()
@@ -780,11 +836,12 @@ class ArtellaDccPlugin(object):
 
         valid_download = True
         while True:
-            dcc_progress_bar.repaint()
-            if dcc_progress_bar.is_cancelled():
-                artella_drive_client.pause_downloads()
-                valid_download = False
-                break
+            if show_dialogs:
+                dcc_progress_bar.repaint()
+                if dcc_progress_bar.is_cancelled():
+                    artella_drive_client.pause_downloads()
+                    valid_download = False
+                    break
             progress, fd, ft, bd, bt = artella_drive_client.get_progress()
             progress_status = '{} | {} of {} KiB downloaded\n{} of {} files downloaded'.format(
                     os.path.basename(file_path), int(bd / 1024), int(bt / 1024), fd, ft)
@@ -795,7 +852,24 @@ class ArtellaDccPlugin(object):
             if progress >= 100 or bd == bt:
                 break
 
-        dcc_progress_bar.end()
+        if show_dialogs:
+            dcc_progress_bar.end()
+
+        total_checks = 0
+        if valid_download:
+            while not os.path.exists(local_path) and total_checks < 5:
+                time.sleep(1.0)
+                total_checks += 1
+            if not os.path.exists(local_path):
+                return False
+            total_checks = 0
+            file_size = os.path.getsize(local_path)
+            while file_size != remote_file_size and total_checks < 5:
+                file_size = os.path.getsize(local_path)
+                time.sleep(1.0)
+                total_checks += 1
+            if file_size != remote_file_size:
+                return False
 
         return valid_download
 
