@@ -339,25 +339,37 @@ class ArtellaPluginsManager(object):
                 continue
 
             # Find specific DCC plugin implementation
-            sub_module = None
             dcc_name = dcc.name()
-            for sub_module_found in sub_modules_found:
-                parent_dir_name = os.path.basename(os.path.dirname(sub_module_found))
-                if parent_dir_name == dcc_name:
-                    sub_module = sub_module_found
+            sub_module = sub_modules_found[0]
+
+            max_length = 50
+            index = 0
+            artella_module_parts = list()
+            temp_sub_module = sub_module
+            while True:
+                if index > max_length:
+                    artella_module_parts = list()
                     break
-            if not sub_module:
-                sub_module = sub_modules_found[0]
+                base_name = os.path.basename(temp_sub_module)
+                if not base_name or base_name == 'artella':
+                    artella_module_parts.append(base_name)
+                    break
+                artella_module_parts.append(base_name)
+                temp_sub_module = os.path.dirname(temp_sub_module)
+                index += 1
+            if not artella_module_parts:
+                module_path = utils.convert_module_path_to_dotted_path(os.path.normpath(sub_module))
+            else:
+                module_path = os.path.splitext('.'.join(reversed(artella_module_parts)))[0]
 
-            module_path = utils.convert_module_path_to_dotted_path(os.path.normpath(sub_module))
-
-            try:
-                sub_module_obj = utils.import_module(module_path)
-            except Exception as exc:
-                logger.error('Error while importing Artella Plugin module: {} | {}'.format(module_path, exc))
-                continue
+            module_path_split = module_path.split('.')
+            dcc_module_path = '{}.{}.{}'.format('.'.join(module_path_split[:-1]), dcc_name, module_path_split[-1])
+            sub_module_obj = utils.import_module(dcc_module_path, skip_exceptions=True)
             if not sub_module_obj:
-                continue
+                sub_module_obj = utils.import_module(module_path)
+                if not sub_module_obj:
+                    logger.error('Error while importing Artella Plugin module: {} | {}'.format(module_path, exc))
+                    continue
 
             plugin_version = None
             module_path_dir = module_path.rsplit('.', 1)[0]
@@ -459,6 +471,9 @@ class ArtellaPluginsManager(object):
             for plugin_resources_path in plugin_resources_paths:
                 if os.path.isdir(plugin_resources_path):
                     dcc.register_dcc_resource_path(plugin_resources_path)
+                    icons_path = os.path.join(plugin_resources_path, 'icons')
+                    if os.path.isdir(icons_path):
+                        dcc.register_dcc_resource_path(icons_path)
 
         self._plugins[plugin_id] = {
             'name': plugin_name,
